Marker Genes
============

Widget provides access to a public database of marker genes.


**Outputs**
- Genes


Database sources:

 - PanglaoDB
 
 	<cite>Oscar Franzén, Li-Ming Gan, Johan L M Björkegren, PanglaoDB: a web server for exploration of mouse and human single-cell RNA sequencing data, Database, Volume 2019, 2019, baz046, https://doi.org/10.1093/database/baz046</cite>
 
 </br>
 
 - CellMarker
  
  	<cite>[CellMarker: a manually curated resource of cell markers in human and mouse.][1] Nucleic Acids Research. 2018.</cite>
 

Data is preprocessed in Orange readable format and it is hosted [here.][2] One can use [Databases update](databases_update.md)
widget to download (or update) files locally.
 
 
[1]:https://academic.oup.com/nar/article/47/D1/D721/5115823
[2]:http://download.biolab.si/datasets/bioinformatics/marker_genes/
 
 
